Un solveur du jeu Compte Est Bon et Mot Le Plus Long issu de Des Chiffres et Des Lettres.

## Le Compte Est Bon

Le Compte Est Bon consiste à l'aide d'un tirage de nombres, d'essayer de reconstituer un nombre à chercher à l'aide d'opérations.

Pour utiliser le compte est bon, j'ai fait une fonction demo:

```python

from dcdljeu import ceb
ceb.demo()
```

La fonction `ceb.generer()` permet de générer un tirage de nombres
